@@ -13,6 +13,12 @@ from drkns.context.sync import sync_in, sync_out
 from drkns.context.forget import forget
 from drkns.runner.run import run
 from drkns.runner.get_execution_plan import get_execution_plan
+from drkns.runner.get_dependency_groups_configuration \
+    import get_dependency_groups_configuration
+from drkns.generation.templateloading.get_generation_template \
+    import get_generation_template
+from drkns.generation.generation.get_formatted_from_groups_configuration \
+    import get_formatted_from_groups_configuration
 from drkns.debug.get_debug_information import get_debug_information
 
 
@@ -24,6 +30,7 @@ class Cli:
         self._force_success: bool = False
         self._summary: bool = False
         self._limit_output: bool = False
+        self._delete: bool = False
 
     def handle(self):
         self._parse_args()
@@ -63,9 +70,14 @@ class Cli:
             self._sync()
             return
 
+        generate_command = 'generate'
+        if self._command == generate_command:
+            self._generate()
+            return
+
         allowed_commands = [
             check_command, clean_command, debug_command, forget_command,
-            list_command, run_command, sync_command
+            list_command, run_command, sync_command, generate_command
         ]
 
         message = 'Unkown command: ' + self._command +\
@@ -98,10 +110,17 @@ class Cli:
             provided_args.pop(index)
             self._limit_output = True
 
+        delete_flag = '--delete'
+        if delete_flag in provided_args:
+            index = provided_args.index(delete_flag)
+            provided_args.pop(index)
+            self._delete = False
+
         for arg in provided_args:
             if arg.find('--') != -1:
                 allowed_flags = [
-                    force_success_flag, summary_flag, limit_output_flag
+                    force_success_flag, summary_flag, limit_output_flag,
+                    delete_flag
                 ]
 
                 message = 'Unkown command flag: ' + arg + \
@@ -186,7 +205,7 @@ class Cli:
         if sync_direction == 'in':
             (return_code, output) = sync_in(target_s3_path)
         else:
-            (return_code, output) = sync_out(target_s3_path)
+            (return_code, output) = sync_out(target_s3_path, self._delete)
 
         successful = return_code == 0
 
@@ -195,6 +214,15 @@ class Cli:
 
         sys.exit(return_code)
 
+    def _generate(self):
+        config_unit = self._get_config_unit()
+        generation_template = get_generation_template('.')
+        groups_configuration = get_dependency_groups_configuration(config_unit)
+        generated = get_formatted_from_groups_configuration(
+            generation_template,
+            groups_configuration)
+        print(generated)
+
     # noinspection PyMethodMayBeStatic
     def _get_config_unit(self) -> ConfigUnit:
         return load('drkns.yml')
